@@ -206,6 +206,7 @@ class EvaluationSpec(object):
         self.target = "localhost"
         self.input_ = SCAPInput()
         self.tailoring = SCAPTailoring()
+        self.result_format = "standard"
         self.profile_id = None
         self.online_remediation = False
         self.cpe_hints = []
@@ -215,6 +216,7 @@ class EvaluationSpec(object):
         ret += "- mode: \t%s\n" % \
             (oscap_helpers.EvaluationMode.to_string(self.mode))
         ret += "- target: \t%s\n" % (self.target)
+        ret += "- result format: \t%s\n" % (self.result_format)
         ret += "- input:\n"
         ret += "  - file: \t%s\n" % (self.input_.file_path)
         if self.input_.temp_file is not None:
@@ -349,11 +351,13 @@ class EvaluationSpec(object):
 
         return cpe_ids
 
-    def select_profile_by_suffix(self, profile_suffix):
+    def select_profile_by_suffix(self, xccdf_id, profile_suffix):
         input_file = self.input_.file_path
         if input_file is None:
             raise RuntimeError("No SCAP content file was set in the EvaluationSpec")
-        profiles = oscap_helpers.get_profile_choices_for_input(input_file, None)
+        profiles = oscap_helpers.get_profile_choices_for_input(
+            input_file, None, xccdf_id
+        )
         profile_id_match = False
         for p in profiles:
             if p.endswith(profile_suffix):
@@ -455,6 +459,10 @@ class EvaluationSpec(object):
             # generated from that.
             ret.extend(["--results-arf", "results.xml"])
 
+            if self.result_format == "stig":
+                # STIG output can't be deduced from ARF output
+                ret.extend(["--stig-viewer", "results-stig.xml"])
+
             ret.append(self.input_.file_path)
 
         elif self.mode == oscap_helpers.EvaluationMode.OVAL:
@@ -479,6 +487,9 @@ class EvaluationSpec(object):
             if self.tailoring.file_path is not None:
                 ret.extend(["--tailoring-file", self.tailoring.file_path])
 
+            if self.input_.xccdf_id is not None:
+                ret.extend(["--xccdf-id", self.input_.xccdf_id])
+
             if self.profile_id is None:
                 ret.extend(["--profile",
                         "xccdf_org.ssgproject.content_profile_standard"])
@@ -492,6 +503,10 @@ class EvaluationSpec(object):
             # generated from that.
             ret.extend(["--results-arf", "results.xml"])
 
+            if self.result_format == "stig":
+                # STIG output can't be deduced from ARF output
+                ret.extend(["--stig-viewer", "results-stig.xml"])
+
             ret.append(config.get_ssg_sds(self.get_cpe_ids(config)))
 
         else:
@@ -520,17 +535,25 @@ class EvaluationSpec(object):
                          encoding="utf-8") as f:
                 stderr = f.read()
 
-            results = ""
+            results = dict()
             try:
+                results["arf"] = ""
                 with io.open(os.path.join(wip_result, "results.xml"), "r",
                              encoding="utf-8") as f:
-                    results = f.read()
+                    results["arf"] = f.read()
             except Exception as e:
                 raise RuntimeError(
                     "Failed to read results.xml of EvaluationSpec evaluation.\n"
                     "stdout:\n%s\n\nstderr:\n%s\n\nexception: %s" %
                     (stdout, stderr, e)
                 )
+            try:
+                with io.open(os.path.join(wip_result, "results-stig.xml"), "r",
+                             encoding="utf-8") as f:
+                    results["stig"] = f.read()
+            except Exception as e:
+                # Results for the STIG viewer may not have been requested at all.
+                pass
 
             return (results, stdout, stderr, exit_code)
 
@@ -559,7 +582,8 @@ class EvaluationSpec(object):
         es.target = target
         es.input_.set_file_path(config.cpe_oval_path)
 
-        results, stdout, stderr, exit_code = es.evaluate(config)
+        all_results, stdout, stderr, exit_code = es.evaluate(config)
+        results = all_results["arf"]
         if exit_code != 0:
             raise RuntimeError("Failed to detect CPEs of target '%s'.\n\n"
                                "stdout:\n%s\n\nstderr:\n%s"
@@ -597,5 +621,5 @@ class EvaluationSpec(object):
         return cpe_ids
 
 
-class ProfileSuffixMatchError(Exception):
+class ProfileSuffixMatchError(RuntimeError):
     pass
