@@ -87,7 +87,7 @@ class System(object):
 
     def get_profile_choices_for_input(self, input_file, tailoring_file):
         return oscap_helpers.get_profile_choices_for_input(
-            input_file, tailoring_file
+            input_file, tailoring_file, None
         )
 
     class AsyncEvaluateSpecAction(async.AsyncAction):
@@ -98,9 +98,13 @@ class System(object):
             self.spec = spec
 
         def run(self):
-            arf, stdout, stderr, exit_code = \
+            all_results, stdout, stderr, exit_code = \
                 self.spec.evaluate(self.system.config)
 
+            arf = None
+            if all_results is not None:
+                arf = all_results["arf"]
+
             with self.system.async_eval_spec_results_lock:
                 self.system.async_eval_spec_results[self.token] = \
                     (arf, stdout, stderr, exit_code)
